﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using OnlineMetodist.API.Data;
using OnlineMetodist.API.Models;

namespace OnlineMetodist.API.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class MethodicalCommissionsController : ControllerBase
    {
        private readonly OnlineMetodistDbContext _context;
        private readonly ILogger<MethodicalCommissionsController> _logger;


        public MethodicalCommissionsController(OnlineMetodistDbContext context, ILogger<MethodicalCommissionsController> logger)
        {
            _context = context;
            _logger = logger;
        }

        // GET: api/MethodicalCommissions
        [HttpGet]
        public async Task<ActionResult<IEnumerable<MethodicalCommission>>> GetMethodicaCommissions()
        {
            try
            {
                var comissions = await _context.MethodicaCommissions.ToListAsync();
                if (comissions == null)
                {
                    _logger.LogError($"MethodicalCommission object sent from client is null.");
                    return BadRequest("MethodicalCommission object sent from client is null.");
                }
                return Ok(comissions);
            }
            catch (Exception ex)
            {
                _logger.LogError($"Something went wrong inside GetMethodicaCommissions action: {ex.Message}");
                return StatusCode(500, "Internal server error");
            }
        }

        // GET: api/MethodicalCommissions/5
        [HttpGet("{id}")]
        public async Task<ActionResult<MethodicalCommission>> GetMethodicalCommission(Guid id)
        {
            try
            {
                var methodicalCommission = await _context.MethodicaCommissions.FindAsync(id);
                if (methodicalCommission == null)
                {
                    _logger.LogError($"MethodicalCommission with id: {id}, hasn't been found in db.");
                    return NotFound();
                }
                return Ok(methodicalCommission);
            }
            catch (Exception ex)
            {
                _logger.LogError($"Something went wrong inside GetMethodicalCommission action: {ex.Message}");
                return StatusCode(500, "Internal server error");
            }
        }

        // PUT: api/MethodicalCommissions/5
        // To protect from overposting attacks, see https://go.microsoft.com/fwlink/?linkid=2123754
        [HttpPut("{id}")]
        public async Task<IActionResult> UpdateMethodicalCommission(Guid id, MethodicalCommission methodicalCommission)
        {
            if (methodicalCommission is null)
            {
                _logger.LogError("FormOfWork object sent from client is null.");
                return BadRequest("FormOfWork object is null");
            }
            if (!ModelState.IsValid)
            {
                _logger.LogError("Invalid FormOfWork object sent from client.");
                return BadRequest("Invalid model object");
            }
            try
            {
                if (!MethodicalCommissionExists(id))
                {
                    _logger.LogError("Invalid id sent from client.");
                    return BadRequest("Invalid id");
                }
                methodicalCommission.Id = id;
                _context.Entry(methodicalCommission).State = EntityState.Modified;
                await _context.SaveChangesAsync();
                return NoContent();
            }
            catch (Exception ex)
            {
                _logger.LogError($"Something went wrong inside UpdateMethodicalCommission action: {ex.Message}");
                return StatusCode(500, "Internal server error");
            }
        }

  //      [HttpPut]
  //      public async Task<IActionResult> ChangeHeadOfMC(Guid idMC, Guid idEmploeyy)
  //      {
  //          try
  //          {
                
  //          }
  //          catch (Exception ex)
  //          {
		//		_logger.LogError($"Something went wrong inside UpdateMethodicalCommission action: {ex.Message}");
		//		return StatusCode(500, "Internal server error");
		//	}
		//}

        // POST: api/MethodicalCommissions
        // To protect from overposting attacks, see https://go.microsoft.com/fwlink/?linkid=2123754
        [HttpPost]
        public async Task<ActionResult<MethodicalCommission>> CreateMethodicalCommission(MethodicalCommission methodicalCommission)
        {
            try
            {
                if (methodicalCommission is null)
                {
                    _logger.LogError("MethodicalCommission object sent from client is null.");
                    return BadRequest("MethodicalCommission object is null");
                }
                if (!ModelState.IsValid)
                {
                    _logger.LogError("Invalid MethodicalCommission object sent from client.");
                    return BadRequest("Invalid model object");
                }
                methodicalCommission.Id = Guid.NewGuid();
                _context.MethodicaCommissions.Add(methodicalCommission);
                await _context.SaveChangesAsync();

                return CreatedAtAction("GetMethodicalCommission", new { id = methodicalCommission.Id }, methodicalCommission);
            }
            catch (Exception ex)
            {
                _logger.LogError($"Something went wrong inside CreateMethodicalCommission action: {ex.Message}");
                return StatusCode(500, "Internal server error");
            }
        }

        // DELETE: api/MethodicalCommissions/5
        [HttpDelete("{id}")]
        public async Task<IActionResult> DeleteMethodicalCommission(Guid id)
        {
            try
            {
                var methodicalCommission = await _context.MethodicaCommissions.FindAsync(id);
                if (methodicalCommission == null)
                {
                    _logger.LogError($"MethodicalCommission with id: {id}, hasn't been found in db.");
                    return NotFound();
                }

                _context.MethodicaCommissions.Remove(methodicalCommission);
                await _context.SaveChangesAsync();

                return NoContent();
            }
            catch (Exception ex)
            {
                _logger.LogError($"Something went wrong inside DeleteMethodicalCommission action: {ex.Message}");
                return StatusCode(500, "Internal server error");
            }
        }

        private bool MethodicalCommissionExists(Guid id)
        {
            return _context.MethodicaCommissions.Any(e => e.Id == id);
        }
    }
}
