﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using OnlineMetodist.API.Data;

namespace OnlineMetodist.API.Controllers
{
	[ApiController]
	[Route("api/[controller]/[action]")]
	[Authorize(Roles = "Администратор")]
	public class RolesController : ControllerBase
	{
		private readonly OnlineMetodistDbContext _context;
		private readonly ILogger<RolesController> _logger;
		private readonly RoleManager<IdentityRole> _roleManager;

		public RolesController(OnlineMetodistDbContext context, ILogger<RolesController> logger, 
			RoleManager<IdentityRole> roleManager)
		{
			_context = context;
			_logger = logger;
			_roleManager = roleManager;
		}

		[HttpGet]
		[AllowAnonymous]
		public async Task<ActionResult<IEnumerable<IdentityRole>>> GetRole()
		{
			try
			{
				var roles = await _roleManager.Roles.ToListAsync();
				if (roles == null)
				{
					_logger.LogError($"Role object sent from client is null.");
					return NotFound("Role object sent from client is null.");
				}
				return Ok(roles);
			}
			catch (Exception ex)
			{
				_logger.LogError($"Something went wrong inside GetRole action: {ex.Message}");
				return StatusCode(500, "Internal server error");
			}
		}

		[HttpGet("{id}")]
		//[Authorize(Roles = "admin")]
		public async Task<ActionResult<IdentityRole>> GetRole(string id)
		{
			try
			{
				IdentityRole? role = await _roleManager.FindByIdAsync(id);
				if (role == null)
				{
					_logger.LogError($"Role with id: {id}, hasn't been found in db.");
					return NotFound();
				}
				return Ok(role);
			}
			catch (Exception ex)
			{
				_logger.LogError($"Something went wrong inside GetRole action: {ex.Message}");
				return StatusCode(500, "Internal server error");
			}			
		}

		//[HttpPut("{id}")]
		//public async Task<IActionResult> UpdateRole(string id, Role model)
		//{

		//	if (model is null)
		//	{
		//		_logger.LogError("Role object sent from client is null.");
		//		return BadRequest("Role object is null");
		//	}
		//	if (!ModelState.IsValid)
		//	{
		//		_logger.LogError("Invalid Role object sent from client.");
		//		return BadRequest("Invalid model object");
		//	}
		//	try
		//	{
		//		IdentityRole? role = _roleManager.Role
		//		if (role is null)
		//		{
		//			_logger.LogError("Invalid id sent from client.");
		//			return BadRequest("Invalid id");
		//		}
		//		role.Id = model.Id;
		//		await _context.SaveChangesAsync();
		//		return NoContent();
		//	}
		//	catch (Exception ex)
		//	{
		//		_logger.LogError($"Something went wrong inside UpdateFormOfWork action: {ex.Message}");
		//		return StatusCode(500, "Internal server error");
		//	}
		//}

		//[HttpPost]
		//public async Task<ActionResult<IdentityRole>> CreateRole(Role model)
		//{
		//	if (!ModelState.IsValid)
		//	{
		//		_logger.LogError("Invalid FormOfWork object sent from client.");
		//		return BadRequest("Invalid model object");
		//	}
		//	if(model.Name is null)
		//	{
		//		_logger.LogError("Role object sent from client is null.");
		//		return BadRequest("Role object is null");
		//	}	
		//	try
		//	{
		//		IdentityRole role = new IdentityRole
		//		{
		//			Id = Guid.NewGuid().ToString(),
		//			Name = model.Name,
		//			NormalizedName = model.NormalizedName
		//		};
		//		var result = await _roleManager.CreateAsync(role);
		//		_context.SaveChanges();
		//		return CreatedAtAction("GetFormOfWork", new { id = role.Id }, role);
		//	}
		//	catch (Exception ex)
		//	{
		//		_logger.LogError($"Something went wrong inside CreateFormOfWork action: {ex.Message}");
		//		return StatusCode(500, "Internal server error");
		//	}
		//}

		//[HttpDelete]
		//public async Task<IActionResult> DeleteRole(string id)
		//{
		//	try
		//	{
		//		IdentityRole role = await _roleManager.FindByIdAsync(id);
		//		if (role == null)
		//		{
		//			_logger.LogError($"FormOfWork with id: {id}, hasn't been found in db.");
		//			return NotFound();
		//		}
		//		await _roleManager.DeleteAsync(role);
		//		await _context.SaveChangesAsync();
		//		return NoContent();
		//	}
		//	catch (Exception ex)
		//	{
		//		_logger.LogError($"Something went wrong inside DeleteFormOfWork action: {ex.Message}");
		//		return StatusCode(500, "Internal server error");
		//	}
		//}
	}

}
