﻿using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore;
using OnlineMetodist.API.Models;

namespace OnlineMetodist.API.Data
{
    public class OnlineMetodistDbContext : IdentityDbContext<ApplicationUser>
    {
        public DbSet<Event> Events { get; set; }
        public DbSet<Employee> Employees { get; set; }
        public DbSet<FormOfWork> FormsOfWorks { get; set; }
        public DbSet<MethodicalCommission> MethodicaCommissions { get; set; }
        public DbSet<ReportingPeriod> ReportingPeriods { get; set; }

        public OnlineMetodistDbContext(DbContextOptions<OnlineMetodistDbContext> options) : base(options)
        {
        }

        //public OnlineMetodistDbContext()
        //{
        //    //    Database.EnsureCreated();
        //}

        //protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        //{
        //    //optionsBuilder.UseNpgsql("Host=ngknn.ru;Port=5432;Database=Information_about_methodical_activity_teachers;Username=Info_method_activ_teachers_Hd21Bd;Password='=Tj@Q2dA<nH2';Pooling=true;SearchPath=testing;");
        //}

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            //для описания сущностей identity
            base.OnModelCreating(modelBuilder);

            //связь между пользователями и сотрудниками
			modelBuilder.Entity<ApplicationUser>()
	           .HasOne(e => e.Employee)
			        .WithOne(e => e.User)
	           .HasForeignKey<Employee>(e => e.UserId)
	           .IsRequired();

            //связь списка сотрудников в МК
            modelBuilder.Entity<MethodicalCommission>()
                .HasMany(e => e.Employees)
                .WithOne(e => e.MethodicalCommission)
                .HasForeignKey(e => e.IdMC)
                /*.IsRequired()*/;

            //связь между МК и его главой
            modelBuilder.Entity<Employee>()
                .HasOne(e=>e.HeadMC)
                .WithOne(e=>e.HeadMC)
                .HasForeignKey<MethodicalCommission>(e => e.IdHead);

			modelBuilder.Entity<FormOfWork>().HasData(
                    new FormOfWork { Id = Guid.NewGuid(), Name = "Проведение" },
                    new FormOfWork { Id = Guid.NewGuid(), Name = "Участие" },
                    new FormOfWork { Id = Guid.NewGuid(), Name = "Публикация" },
                    new FormOfWork { Id = Guid.NewGuid(), Name = "Стажировка" }
            );

            modelBuilder.Entity<MethodicalCommission>().HasData(
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Математических и естественно - научных дисциплин" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Гуманитарных дисциплин" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Иностранного языка" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Дисциплин физической культуры и БЖД" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Общественных и правовых дисциплин" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Информатика и вычислительная техника" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Экономика и управление, логистика" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Специальностей Товароведение, Коммерция" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Специальностей Банковское дело, ДОУ" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Инструментальных дисциплин" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Музыкальных дисциплин" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Специальности Дошкольное образование" },
                    new MethodicalCommission { Id = Guid.NewGuid(), Name = "Специальности Преподавание в начальных классах" }
            );

			modelBuilder.Entity<IdentityRole>().HasData(
                new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Администратор", NormalizedName = "ADMIN".ToUpper() },
                new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Заведующий корпусом", NormalizedName = "ZAVED".ToUpper() },
                new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Представитель НМЦ", NormalizedName = "PREDSTAV".ToUpper() },
                new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Председатель МК", NormalizedName = "PREDSED".ToUpper() },
                new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Преподаватель", NormalizedName = "PREPOD".ToUpper() }
                );

        }
    }
}
