﻿using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore;
using OnlineMetodist.API.Models;

namespace OnlineMetodist.API.Data
{
	public static class SeedData
	{
		public static void Initialize(IServiceProvider serviceProvider)
		{
			using (var context = serviceProvider.GetRequiredService<OnlineMetodistDbContext>())
			//new OnlineMetodistDbContext(
			//serviceProvider.GetRequiredService<
			//    DbContextOptions<OnlineMetodistDbContext>>()))
			{
				// Look for any movies.
				if (!context.Roles.Any())
				{
					var roleStore = new RoleStore<IdentityRole>(context);
					List<IdentityRole> roles = new()
					{
						new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Администратор", NormalizedName = "ADMIN".ToUpper() },
						new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Заведующий корпусом", NormalizedName = "ZAVED".ToUpper() },
						new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Представитель НМЦ", NormalizedName = "PREDSTAV".ToUpper() },
						new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Председатель МК", NormalizedName = "PREDSED".ToUpper() },
						new IdentityRole { Id = Guid.NewGuid().ToString(), Name = "Преподаватель", NormalizedName = "PREPOD".ToUpper() }
					};

					foreach (var role in roles)
					{
						roleStore.CreateAsync(role);
					}
				}

				var user = new ApplicationUser
				{
					UserName = "adm@test.ru",
					//NormalizedUserName = "adm@test.ru",
					Email = "adm@test.ru",
					//NormalizedEmail = "adm@test.ru",
					LockoutEnabled = false,
					SecurityStamp = Guid.NewGuid().ToString()
				};


				if (!context.Users.Any(u => u.UserName == user.UserName))
				{
					var password = new PasswordHasher<IdentityUser>();
					var hashed = password.HashPassword(user, "password");
					user.PasswordHash = hashed;
					var userStore = new UserStore<IdentityUser>(context);
					userStore.CreateAsync(user);
					userStore.AddToRoleAsync(user, "Администратор");
				}

				context.SaveChangesAsync();
			}
		}

		public static async Task InitializeAsync(UserManager<ApplicationUser> userManager, RoleManager<IdentityRole> roleManager)
		{
			var adminEmail = new ConfigurationBuilder().AddJsonFile("appsettings.json").Build().GetSection("SiteSettings")["AdminEmail"];
			var adminPassword = new ConfigurationBuilder().AddJsonFile("appsettings.json").Build().GetSection("SiteSettings")["AdminPassword"];

			await CreateAdminUser(userManager, roleManager, adminEmail, adminPassword);
		}

		private static async Task CreateAdminUser(UserManager<ApplicationUser> userManager, RoleManager<IdentityRole> roleManager, string userEmail, string userPassword)
		{
			if (await userManager.FindByEmailAsync(userEmail) == null)
			{
				ApplicationUser admin = new ApplicationUser { Email = userEmail, UserName = userEmail };
				IdentityResult result = await userManager.CreateAsync(admin, userPassword);
				if (result.Succeeded)
				{
					List<IdentityRole> roles = await roleManager.Roles.ToListAsync();
					foreach (IdentityRole role in roles)
					{
						await userManager.AddToRoleAsync(admin, role.NormalizedName);
					}
				}
			}
		}
	}
}
